Exposure to biological substances is prevented or controlled. | OiRA

Help

1. Preparación
2. Implicación
3. Identificación + Evaluación
   1. 1 Commercial manned guarding
      1. 1.1 Work environment (site related)
         1. 1.1.1 Slips, trips and falls are prevented.
         2. 1.1.2 Collisions, bumps, and jamming are prevented.
         3. 1.1.3 The electricity, gas and water supplies are in order and well-maintained.
         4. 1.1.4 Exposure to noise is prevented or controlled.
         5. 1.1.5 Exposure to chemical substances is prevented or controlled.
         6. 1.1.6 Exposure to biological substances is prevented or controlled.
         7. 1.1.7 Exposure to radiation is prevented or controlled.
         8. 1.1.8 Risks from ambient factors are prevented.
         9. 1.1.9 All necessary facilities are available and well maintained.
      2. 1.2 Fire prevention and emergency procedures
   2. Ω Riesgos añadidos (por Ud)
   - Sin respuesta
   - Pospuesto
   - OK
   - Atención
4. Plan de acción
5. Informe
6. Grado de cumplimentación 0%

Help

## Exposure to biological substances is prevented or controlled.

Sí No No procede

Exposure to biological substances is neither prevented nor controlled

Responda a las siguientes preguntas. Como resultado de sus respuestas, el sistema calculará la prioridad del riesgo. Podrá modificar la prioridad más tarde.

¿Cuál es la probabilidad de que se produzca el riesgo? Indicate how likely occurence of this risk is in a normal situation. Pequeña Media Grande
¿Con qué frecuencia está expuesta la gente a este riesgo? Indicate how often this risk occurs in a normal situation. Casi nunca Regular Constante
¿Cuál es la gravedad del daño? Indicate the default severity of this risk occurs. Gravedad débil Gravedad importante Gravedad alta (muy alta)

### Información

BIOLOGICAL HAZARDS

- What? Biological agents, i.e. microorganisms, cell cultures and parasites living in the human body, which may cause infections, allergies or poisoning. These microorganisms can penetrate the human body through a wound, an animal bite or needle injuries. They can also be inhaled or swallowed. There is a risk of viral and bacteriological infections such as HIV, hepatitis or tuberculosis, tetanus, legionella, …
- Who? All private security staff in specific work environments such as hospitals or with eventual biological risks.

Make sure the client informs you (the private security services company) and the private security guards about the risks and measures in place (e.g. required vaccinations).

### Recursos

#### Referencias legales y de políticas

- 89/391/CEE Implementing measures to improve the health and safety of workers (framework directive).
- 89/654/EEC Directive on the minimum safety and health requirements for the workplace.
- 2000/54/EC Directive on the protection of workers from risks related to exposure to biological agents at work.

#### Recursos adicionales para evaluar el riesgo

- Lorem ipsum dolor sit.pdf
- Amet consectetuer.pdf

Comentarios

Scroll to top
Back

## 2014-01-08-exposure-to-biological-substances-is-prevented-or-controlled.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More